@@ -644,6 +644,203 @@ function main (cxt) {
         this.label++;
     }, cxt, { immediate: true });
 
+    def('?do', function () {
+        var oldpos;
+        oldpos = this.pos;
+        this.cfs.push(oldpos);
+        this.pos = [];
+        oldpos.push({
+            type: Syntax.ExpressionStatement,
+            expression: {
+                type: Syntax.CallExpression,
+                callee: {
+                    type: Syntax.MemberExpression,
+                    computed: false,
+                    object: {
+                        type: Syntax.ThisExpression
+                    },
+                    property: {
+                        type: Syntax.Identifier,
+                        name: 'rpush'
+                    }
+                },
+                arguments: [
+                    {
+                        type: Syntax.CallExpression,
+                        callee: {
+                            type: Syntax.MemberExpression,
+                            computed: false,
+                            object: {
+                                type: Syntax.ThisExpression
+                            },
+                            property: {
+                                type: Syntax.Identifier,
+                                name: 'dnext'
+                            }
+                        },
+                        arguments: []
+                    }
+                ]
+            }
+        }); // limit
+        oldpos.push({
+            type: Syntax.ExpressionStatement,
+            expression: {
+                type: Syntax.CallExpression,
+                callee: {
+                    type: Syntax.MemberExpression,
+                    computed: false,
+                    object: {
+                        type: Syntax.ThisExpression
+                    },
+                    property: {
+                        type: Syntax.Identifier,
+                        name: 'rpush'
+                    }
+                },
+                arguments: [
+                    {
+                        type: Syntax.CallExpression,
+                        callee: {
+                            type: Syntax.MemberExpression,
+                            computed: false,
+                            object: {
+                                type: Syntax.ThisExpression
+                            },
+                            property: {
+                                type: Syntax.Identifier,
+                                name: 'dpop'
+                            }
+                        },
+                        arguments: []
+                    }
+                ]
+            }
+        });
+        oldpos.push({
+            type: Syntax.ExpressionStatement,
+            expression: {
+                type: Syntax.CallExpression,
+                callee: {
+                    type: Syntax.MemberExpression,
+                    computed: false,
+                    object: {
+                        type: Syntax.ThisExpression
+                    },
+                    property: {
+                        type: Syntax.Identifier,
+                        name: 'dpop'
+                    }
+                },
+                arguments: []
+            }
+        });
+        oldpos.push({
+            type: Syntax.LabeledStatement,
+            label: {
+                type: Syntax.Identifier,
+                name: 'L' + this.label
+            },
+            body: {
+                type: Syntax.DoWhileStatement,
+                body: {
+                    type: Syntax.BlockStatement,
+                    body: this.pos
+                },
+                test: {
+                    type: Syntax.Literal,
+                    value: true,
+                    raw: 'true'
+                }
+            }
+        });
+        this.pos.push({
+            type: Syntax.IfStatement,
+            test: {
+                type: Syntax.BinaryExpression,
+                operator: '===',
+                left: {
+                    type: Syntax.CallExpression,
+                    callee: {
+                        type: Syntax.MemberExpression,
+                        computed: false,
+                        object: {
+                            type: Syntax.ThisExpression
+                        },
+                        property: {
+                            type: Syntax.Identifier,
+                            name: 'rtop'
+                        }
+                    },
+                    arguments: []
+                },
+                right: {
+                    type: Syntax.CallExpression,
+                    callee: {
+                        type: Syntax.MemberExpression,
+                        computed: false,
+                        object: {
+                            type: Syntax.ThisExpression
+                        },
+                        property: {
+                            type: Syntax.Identifier,
+                            name: 'rnext'
+                        }
+                    },
+                    arguments: []
+                }
+            },
+            consequent: {
+                type: Syntax.BlockStatement,
+                body: [
+                    {
+                        type: Syntax.ExpressionStatement,
+                        expression: {
+                            type: Syntax.CallExpression,
+                            callee: {
+                                type: Syntax.MemberExpression,
+                                computed: false,
+                                object: {
+                                    type: Syntax.ThisExpression
+                                },
+                                property: {
+                                    type: Syntax.Identifier,
+                                    name: 'rpop'
+                                }
+                            },
+                            arguments: []
+                        }
+                    },
+                    {
+                        type: Syntax.ExpressionStatement,
+                        expression: {
+                            type: Syntax.CallExpression,
+                            callee: {
+                                type: Syntax.MemberExpression,
+                                computed: false,
+                                object: {
+                                    type: Syntax.ThisExpression
+                                },
+                                property: {
+                                    type: Syntax.Identifier,
+                                    name: 'rpop'
+                                }
+                            },
+                            arguments: []
+                        }
+                    },
+                    {
+                        type: Syntax.BreakStatement,
+                        label: null
+                    }
+                ]
+            },
+            alternate: null
+        });
+        this.label++;
+    }, cxt, { immediate: true });
+
+
     def('loop', function () {
         this.pos.push({
             type: Syntax.ExpressionStatement,
@@ -854,6 +1051,46 @@ function main (cxt) {
     }, cxt, { immediate: true });
 
     def('leave', function () {
+        this.pos.push({
+            type: Syntax.ExpressionStatement,
+            expression: {
+                type: Syntax.CallExpression,
+                callee: {
+                    type: Syntax.MemberExpression,
+                    computed: false,
+                    object: {
+                        type: Syntax.ThisExpression
+                    },
+                    property: {
+                        type: Syntax.Identifier,
+                        name: 'rpop'
+                    }
+                },
+                arguments: []
+            }
+        });
+        this.pos.push({
+            type: Syntax.ExpressionStatement,
+            expression: {
+                type: Syntax.CallExpression,
+                callee: {
+                    type: Syntax.MemberExpression,
+                    computed: false,
+                    object: {
+                        type: Syntax.ThisExpression
+                    },
+                    property: {
+                        type: Syntax.Identifier,
+                        name: 'rpop'
+                    }
+                },
+                arguments: []
+            }
+        });
+        this.pos.push({
+            type: Syntax.BreakStatement,
+            label: null
+        });
     }, cxt, { immediate: true });
 
     def('i', function () {
