@@ -5,7 +5,6 @@ var def = require('./def'),
     expect = require('chai').expect;
 
 function core (cxt) {
-
     cxt.base = 10;
     var stash = {};
 
@@ -22,11 +21,11 @@ function core (cxt) {
 // Cause subsequent output to appear at the beginning of the next line.
 
     def('cr', function () {
-        console.log();
+        cxt.log('\n');
     }, cxt);
 
     def('.', function () {
-        console.log(' ' + this.dpop());
+        cxt.log(' ' + this.dpop());
     }, cxt);
 
 // 6.1.0895 CHAR “char” (CORE)
@@ -68,14 +67,14 @@ function core (cxt) {
         try {
             expect(stash.DS).deep.equal(this.DS);
         } catch (err) {
-            lines = this.io.buf.slice(0, this.io.ptr).split('\n');
-            console.log('\n' + colors.red('Error:') + ' in line: ' + (lines.length - 1));
+            lines = this.io.buf.toString().slice(0, this.io.ptr).split('\n');
+            cxt.log('\n' + colors.red('Error:') + ' in line: ' + (lines.length - 1) + '\n');
             l0 = lines.pop();
             l1 = lines.pop();
-            console.log(l1 + '\n' + l0);
-            console.log(err.message);
+            cxt.log(l1 + '\n' + l0 + '\n');
+            cxt.log(err.message);
         }
-        console.log('.');
+        cxt.log('.\n');
     }, cxt);
 }
 
