@@ -73,7 +73,7 @@ def('end-code', function () {
             }
             return e.name;
         }, this);
-        console.log(list.join(' ') + '\n');
+        cxt.log(list.join(' ') + '\n');
     }, cxt);
 
 /*
@@ -93,8 +93,8 @@ def('end-code', function () {
         // var list = this.L.map(function (e) {
         //     return colors.green(e.name) + ': ' + this[this.O[e.name].index];
         // }, this);
-        // console.log(list.join('\n'));
-        console.log(colors.green(w) + ': ' + this[this.O[w].index] + '\n');
+        // cxt.log(list.join('\n'));
+        cxt.log(colors.green(w) + ': ' + this[this.O[w].index].toString() + '\n');
     }, cxt);
 
 // 6.1.0070 ' “tick” (CORE)
@@ -109,7 +109,7 @@ def('end-code', function () {
         if (wordLink) {
            this.dpush(wordLink.index);
         } else {
-            console.log('word: ' + w + ' is not defined');
+            cxt.log('word: ' + w + ' is not defined');
             throw new Error;
         }
     }, cxt);
