@@ -1,6 +1,7 @@
 'use strict';
 
-var stack = require('./stack'),
+var stream = require('stream'),
+    stack = require('./stack'),
     core = require('./core'),
     memory = require('./memory'),
     interpret = require('./interpret'),
@@ -13,6 +14,7 @@ var stack = require('./stack'),
 */
 function forth () {
     var v = {
+        s: stream.Duplex(),
         pkg: pkg,
         L: [],
         O: {}
