@@ -8,8 +8,13 @@ var def = require('./def');
 function stack (cxt) {
     cxt.DS = [];
     cxt.RS = [];
+    cxt.dtop = function () { return this.DS[this.DS.length - 1]; },
+    cxt.dnext = function () { return this.DS[this.DS.length - 2]; },
     cxt.dpop = function () { return this.DS.pop(); },
     cxt.dpush = function (e) { this.DS.push(e); };
+    cxt.rtop = function () { return this.RS[this.RS.length - 1]; },
+    cxt.rnext = function () { return this.RS[this.RS.length - 2]; },
+    cxt.rpick2 = function () { return this.RS[this.RS.length - 3]; },
     cxt.rpop = function () { return this.RS.pop(); },
     cxt.rpush = function (e) { this.RS.push(e); };
 
@@ -19,15 +24,11 @@ function stack (cxt) {
             this.dpop();
         },
         dup: function () {
-            var t = this.dpop();
-            this.dpush(t);
+            var t = this.dtop();
             this.dpush(t);
         },
         over: function () {
-            var t = this.dpop();
-            var n = this.dpop();
-            this.dpush(n);
-            this.dpush(t);
+            var n = this.dnext();
             this.dpush(n);
         },
         swap: function () {
@@ -43,8 +44,7 @@ function stack (cxt) {
             this.dpush(this.rpop());
         },
         'r@': function () {
-            var rtop = this.rpop();
-            this.rpush(rtop);
+            var rtop = this.rtop();
             this.dpush(rtop);
         },
         // 6.1.0100 */ ( n1 n2 n3 -- n4 ) “star-slash” (CORE)
