@@ -1,18 +1,12 @@
 'use strict';
 
-var stack = require('../lib/stack'),
-    memory = require('../lib/memory'),
-    // word = require('../lib/word'),
-    // create = require('../lib/create'),
-    interpret = require('../lib/interpret'),
+var forth = require('../lib'),
     expect = require('chai').expect;
 
 describe('#interpret', function () {
 
-    it('#stack', function (done) {
-        var test = { L: [], O: {} };
-        stack(test);
-        interpret(test);
+    it('#literal swap dup nip drop over +', function (done) {
+        var test = forth();
 
         expect(test.DS).to.deep.equal([]);
         test.interpret(' 6    7     ', function () {
@@ -21,8 +15,8 @@ describe('#interpret', function () {
                 expect(test.DS).to.deep.equal([7, 6]);
                 test.interpret(' dup 5 nip ', function () {
                     expect(test.DS).to.deep.equal([7, 6, 5]);
-                    test.interpret(' drop OVER * nip', function () {
-                        expect(test.DS).to.deep.equal([42]);
+                    test.interpret(' drop OVER + nip', function () {
+                        expect(test.DS).to.deep.equal([13]);
                         done();
                     });
                 });
@@ -30,11 +24,8 @@ describe('#interpret', function () {
         });
     });
 
-    it('#memory', function (done) {
-        var test = { L: [], O: {} };
-        stack(test);
-        memory(test);
-        interpret(test);
+    it('#literal ! @ *', function (done) {
+        var test = forth();
 
         expect(test.DS).to.deep.equal([]);
         test.interpret(' 6 0 !   7 4 !  0 @ 4 @ *  ', function () {
